#
# spec file for package cosmic-comp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cosmic-comp
Version:        1.0.0~alpha7+1
Release:        1.1
Summary:        Compositor for the COSMIC DE
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-comp
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libdisplay-info)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libseat)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xkbcommon)
Requires:       Mesa-libEGL1
Recommends:     Mesa-libGL1

%description
%{summary}.

%prep
%autosetup -a1

%build
%make_build

%install
%make_install
install -d %{buildroot}%{_sysconfdir}/%{name}

%check
%{cargo_test}

%files
%license LICENSE
%{_bindir}/%{name}
%{_sysconfdir}/%{name}
%{_datadir}/cosmic

%changelog
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 1.0.0~alpha7+1:
  * i18n (pt-BR) - Update translations
  * Initial support for workspace pinning and moving
  * protocols/workspace: Make `move_workspace_to_group` move existing handle
  * protocols/workspace: Store request queue in workspace manager udata
  * protocol/workspace: Store manager as part of workspace/group udata
  * protocol/workspace: Move `WorkspaceGroupData` to `ext.rs`
  * protocol/workspace: Remove type bounds that aren't required
  * protocol/workspace: Drop support for cosmic v1 protocol
  * xwayland: Set scaled cursor size via xsettings
  * render/cursor: Don't round cursor coordinates early
  * render/cursor: Correctly convert hotspot coordinates
  * i18n(cs): Add Czech translations
  * shell: Don't engage new MoveGrabs while in Overview
  * chore: use cosmic-text shape cache
  * xwayland: Honor primary output for fractional scale
  * output_configuration: Allow setting xwayland primary output
  * chore: update cosmic-protocols
  * xwayland: store and restore primary output
  * feat: Allow fractional xwayland client scale
  * chore: update smithay
  * Change default X11 eavesdropping to None
  * shell/element: Attach a resize border to tiled undecorated windows
  * chore: Update smithay
  * state: Use `WeakOutput` for frame trottling
  * xwayland: Allow eavesdropping on certain keyboard/pointer events
  * chore: Update smithay
  * xwayland: Always allow writing into clipboard
  * xwayland: Allow pasting into fullscreen surfaces
  * shell/workspace: Disambiguate output with edid match by connector name
  * shell/workspace: Store edid in output stack
  * shell/workspace: Clear output stack when moved user moves workspace
  * Add `EdidProduct`, as user data for kms `Output`s
  * Replace screencopy with `ext-image-copy-capture-v1`
  * config: Refactor WorkspaceLayout to use the Default macro
  * Argument support with clap_lex
  * i18n(sk): Add Slovak translations
  * a11y/zoom: Fix settings page
  * input: Don't trigger modifier shortcuts, when zooming
  * a11y/zoom: Add more leeway for OnEdge movement
  * a11y/zoom: zoom level per output
  * a11y/zoom: Drop last state
  * a11y/zoom: Allow disabling scroll-shortcuts
  * a11y/zoom: Allow hiding the overlay
  * xdg-activation/toplevel-management: Unmaximize when activating a tiled window
  * shell: Unmaximize when moving a single window to another tiling layer
  * shell: Unmaximize windows on the target workspace when moving groups
  * shell: Don't move group to tiled layer of floating-only workspace
  * kms: Support screencopy cursor modes with active filters
  * backend: Support screen filters in nested mode
  * chore: Update smithay
  * kms: Support screen filters
  * kms: Refactor out postprocessing helpers
  * wayland: Add support for cosmic-a11y version 2
  * chore: Update cosmic-protocols
  * config: Add screen-filter configuration and persistent state
  * screencopy: Remove unnecessary lifetime
  * Call `underlying_storage` of `TextureRenderElement` without mapping
  * kms.timings.presented: print debug msg when frame time is overflowing
  * kms: protect against potential overflow of Duration when calculating avg frametime
  * shell: Refactor out common code for removing workspace from set
  * Fixes for `migrate_workspace`
  * Refactor out duplicated `workspace_set_idx` loops
  * Send one-dimensional workspace coordinates, without output index
  * Take slice instead of array in `set_workspace_coordinates`
  * Improve handling of XDG activation tokens in shell
  * Update `smithay`
  * Fix `dependency_on_unit_never_type_fallback` warning on latest Rustc
  * chore: Update rust toolchain
  * iced: Don't call update from render_elements
  * iced: Don't throttle resizes
  * input: Fix events for subsurfaces of lock surface
  * fix: Remove extra scaling of borders
  * chore: smithay update
  * shell: On `output_remove`, focus moved workspace instead of empty one
  * protocol/workspace: Store ext/cosmic specific capabilities
  * protocol/workspace: Split ext/cosmic-v1 workspace data into two types
  * shell: If active workspace moved, add `WState::Active` to new active
  * shell: Fix getting `active_handle` for `other_set`
  * tiling: Exclude maximized windows from input/render
  * iced: refresh after output_enter
  * floating: Refresh space after mapping
  * main: throttle refresh
  * i18n (pt-BR) update translation
  * i18n(pt): update Portuguese translation
  * Create cosmic_comp.ftl (Swedish)
  * i18n(nl) update Dutch translation
  * shell: next_output - axis overlap filter logic without negation
  * actions: Remember previous workspace on extended action
  * actions: Shortcut handling changes for #1005
  * stack: Remember position during continuous move action
  * stack: Remember previous position during focus navigation
  * ci: Update unsupported cache v2 action to v4
  * fix(protocol/workspace): Handle cosmic-workspace-v2 destroy requests
  * Add `cosmic-workspace-v2`, image source, toplevel info changes
  * Update cosmic-protocols
  * Set `WorkspaceCapabilities::SetTilingState` capability
  * protocol/toplevel_management: Use `WorkspaceHandle` in argument
  * protocol/workspace: Fix initial sending of states and capabilities
  * feat: add shortcut for input source switch
  * i18n(pl): update translation
  * Update Hungarian translations
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+0:
  * stack: Fix input at bottom of window
  * grabs/resize: Fix Xwayland geometry
  * zoom: bugfixes
  * wayland: Implement cosmic-a11y-v1
  * chore: Cleanup some warnings
  * zoom: Add separator to popup
  * zoom: Be a little more lenient with OnEdge movement and fractional cursor positions
  * zoom: Seperate animating/current focal_point
  * zoom: Reload config after writing
  * config: Update zoom config defaults
- switch to obs_scm
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5.1+0:
  * stack: Fix input at bottom of window
  * grabs/resize: Fix Xwayland geometry
  * zoom: bugfixes
  * wayland: Implement cosmic-a11y-v1
  * chore: Cleanup some warnings
  * zoom: Add separator to popup
  * zoom: Be a little more lenient with OnEdge movement and fractional cursor positions
  * zoom: Seperate animating/current focal_point
  * zoom: Reload config after writing
  * config: Update zoom config defaults
  * zoom: Fix config/state changes
  * zoom: Localize zoom ui
  * shell: Rescale zoom UI with zoom factor
  * zoom: Don't render at 100%% scale while animating
  * iced: Allow rendering at a higher native scale than it's output
  * shell: Add zoom UI
  * config: Handle zoom updates in `Common::update_config`
  * iced: Track last seat/serial for grabs
  * grab: Refactor `MenuGrab` to be useful for zoom ui
  * input: Refactor common logic into `update_zoom`
  * input: Zoom on Super+Scroll
  * config: Read/store zoom state
  * shell: Cleanup zoom state
  * shell: Reset focal point if cursor outside OnEdge area
  * shell: don't accidentally reset zoom when using multiple seats (theoretically)
  * chore: Update cosmic-settings-config
  * zoom: Handle multiple outputs
  * utils: Move `NextDown`
  * config: Add zoom configuration
  * shell: Allow triggering zoom
  * render: Scale contents according to zoom_level
  * chore: Update libcosmic
  * floating: Fix resize indicator order
  * Derive Eq for NumlockState
  * Update moving.rs
  * grabs: Snap Window Edges to Close Output Edges
  * Reactivated num/caps-lock upon keyboard layour change
  * protocol/workspace: Fix behavior with multiple manager instances
  * protocol/workspace: Add support for `ext-workspace-v1`
  * protocol/workspace: Move cosmic dispatch code to seperate file
  * Make numlock state on boot configurable
  * Update `libcosmic`
  * chore: Update smithay
  * layout/floating: Fix indicator element order
  * layout/tiling: Fix swap stack overlay offset
  * layout/tiling: Fix swap indicator element order
  * render: Scale indicator radius with scale
  * chore: ron 0.9 update
  * render/cursor: Follow selected scale instead of wanted scale
  * chore: Update cosmic-config for forward compatibility
  * wl_compositor: Send initial size for maximized/fullscreen surfaces
  * shell: Don't animate programmatic maximize_requests
  * shell: Handle maximize requests before commit
  * Improve mirroring size/scale comparison
  * Fix mirroring with scale on target output
  * Use `HashMap` entry API in a cleaner way
  * Use untransformed texture in `MirroringState::new_with_renderer`
  * shell: Remove last workspace if it follows empty active workspace
  * fix(config): wrong config context for system actions on startup
  * Remove `CosmicMapped::stack_ref_mut`
  * toplevel-management: Move window, not whole stack
  * toplevel-management: Make `move_to_workspace` work with minimized window
  * workspace: Fix race between binding `wl_output` and `output_enter`
  * kms: Don't try to render inactive outputs
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+13:
  * chore: add log-out shortcut
  * Only cancel the keyboard grabs that we initiate
  * floating/resize: Fix broken global geometry
  * toplevel_info: Don't send geometry updates, while resizing
  * tiling: Refactor blocker code
  * tiling: Throttle resizes
  * tiling: Fix flicker during resizing
  * floating: Throttle resizes
  * mapped: Allow to query in-flight configure for resize throttling
  * Add a `COSMIC_DISABLE_SYNCOBJ` env var to disable syncobj protocol
  * Add `linux-drm-syncobj-v1` protocol
  * Update `smithay-egui`, `egui`
  * Use `get_unconstrained_geometry` function for popup position
  * fix: cosmic-protocols rev
  * chore: Downgrade Cargo.lock version
  * chore: update freedesktop-icons
  * add Dutch translation
  * Remove unused `glow` and `drm-ffi` dependencies
  * chore: Update smithay
  * chore: cargo update
  * chore: Update libcosmic
  * chore: Update cosmic-text
  * fix: add missing libdisplay-info library into flake.nix
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+0:
  * toplevel-info: Send initial `state` even if empty
  * kms: Don't try to restore modifiers, if we don't have any surfaces
  * output_configuration: Better log errors
  * Use `Mul` impl of `Size`
  * Migrate away from `Rectangle::from_loc_and_size`
  * chore: Update `smithay`
  * render: Fix race during startup
  * chore: github-ci was also missing pixman apparently
  * chore: Add libdisplay-info to github ci
  * kms: Use scaled sizes for placing new outputs
  * kms: Cleanup now that `output_elements` won't panic for uninitialized outputs
  * shell: Allow active workspace to be `None`
  * chore: Add libdisplay-info dependency for packaging
  * debug: Fixup feature compilation
  * kms: Allow diverging primary plane formats under certain conditions
  * kms: skip cursor updates for fullscreen content above the minimum refresh rate
  * deps: Switch from edid-rs to libdisplay-info
  * drm_lease: Disable overlay planes when active
  * kms: Use new `DrmOutput` api
  * xdg_activation: Also consider tiled windows
  * chore: Fix a few warnings
  * chore: Update smithay
  * Update leds when devices are added
  * Fix sticky toggle crashes on maximized windows (#1110)
  * refactor(shell/element): refactor how decorations height is accessed
  * When removing output global, use `disable_global`, remove with timer
  * focus: Fix active/focused output on `refresh_focus`
  * shell: Fix stacking maximized windows
  * toplevel-info: Fix behavior with multiple instances of global
  * shell: Unset focused outputs on `remove_output`
  * kms/surface: Fix racy output disable
  * fix: manually scale the damage
  * fix: improve damage tracking
  * fix(iced): use internal_ref size
  * chore: update deps
  * feat: alt+shift+tab
  * chore: update iced/libcosmic
  * Call `data_init.init` even if weak references are not alive
  * output_configuration: Use `unwrap` in calls to `Resource::data`
  * Use `WeakOutput` when accessing data of `ZwlrOutputHeadV1`
  * fix: activation of an element outside the current workspace
  * main: Update D-Bus activation environment also on non-systemd systems
  * focus: Only consider focused output
  * focus: Un-activate non-active workspaces
  * fix: filter by active workspace in overlap notify
  * shell: Fix windows global geometry to include ssd
* Thu Dec  5 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * focus: Only consider focused output
  * focus: Un-activate non-active workspaces
  * fix: filter by active workspace in overlap notify
  * shell: Fix windows global geometry to include ssd
  * input: Apply output transform to touch/tablet events
  * input: Define function for transforming touch/tablet event position
  * screencopy: don't force opaque window backgrounds
  * refactor: add namespace
  * overlay-notify: Implement handler
  * overlap-notify: Implementation fixes
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * Add cosmic_atspi_v1 protocol
  * element/window: Input offset fixes
  * toplevel_info: Fix racy data creation
  * kms: Don't substract for mirrored outputs
  * DPMS with wlr-output-power-management-unstable-v1 protocol
  * set cursor shape for resize grabs
  * focus: Fix layer-popup locations
  * input: Use render_input_order
  * render: Use render_input_order
  * focus: Introduce render_input_order
  * Don't create initial empty workspace when there are other workspaces
  * On adding output add set after processing other sets
  * Fix workspace indices when workspace is moved to another output
  * Preserve active workspace when workspaces are moved back to another
    output
  * When moving workspaces on output remove, don't movve empty workspace
  * Fix spelling of prefers
  * Use to_ne_bytes() instead of unsound Vec::from_raw_parts
  * fix(menu): use corner radius from theme
  * Add COSMIC_DISABLE_DIRECT_SCANOUT env var
  * Add util function for boolean env vars
  * cursor follows focus to center of window
  * fix(window): center window title
  * fix(menu): styling
  * use Grabbing cursor instead of Grab cursor
  * input: Treat pointer-shortcuts as potentially inhibited
  * Set default output transform based on DRM panel orientation
  * Update egui, smithay-egui, smithay
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * Use EGL_MESA_device_software as fallback for screen capture
  * iced: Set default font
  * Add wl-clipboard to tiling exceptions
  * kms: Try to calculate dpi and scale factor
  * Use fallback scale if size is invalid
  * screencopy: Use buffer age of 0 for render to temporary buffer
  * Add xdg-foreign-unstable-v2 protocol
  * xwayland: Add descaling option
  * added cursor_follows_focus and focus_follows_cursor
  * Use new config from cosmic-settings-config
  * Add config reloading for tiling exceptions
  * Apply suggestions from code review
  * wayland: Implement cursor-shape-v1
  * input: Move actions into own module
  * actions: Fix focus on Output-actions
  * input: Fix passed button events
  * fix: add wayland, x11 libraries in runtime
  * Destroy X11Wm when we lose connect to X server
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * reduce duplication
  * add PlayPause/Prev/Next shortcuts
  * fix round corners
  * add translations
- enable leap (thanks to vyvir)
* Sat Jul  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 0.1.0+git20240705.11914e9:
  * Use `FromGlesError` instead of `OutputNoMode` placeholder
  * screencopy: Handle error from `with_buffer_contents_mut`
  * shell: Don't check grab-conditions for SSD grabs
  * tiling: Don't crash when swapping with group
  * shell: Populate focus_stack when unstacking
  * focus: Fall back to first window, if stack is empty
  * shell: Don't skip over Group-targets for next_focus
  * chore: smithay update
  * feat: runtime configurable keybindings
  * xwayland: Fix offset x11 geometry after configure request
* Wed Mar 13 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
